@@ -1,9 +1,12 @@
 import ast
 import asyncio
+import dataclasses
 import re
 from copy import deepcopy
+from typing import List, Optional, Tuple
 
 import pyjq
+from aiohttp import ClientSession
 from jinja2 import Environment, StrictUndefined, Template, meta
 from pydantic import Field
 from toucan_data_sdk.utils.helpers import slugify
@@ -204,3 +207,30 @@ def get_loop():
         asyncio.set_event_loop(loop)
 
     return loop
+
+
+async def fetch(url: str, session: ClientSession):
+    """Fetch data from an API."""
+    async with session.get(url) as res:
+        if res.status != 200:
+            raise HttpError(
+                f'Aborting request due to error from the API: {res.status}, {res.reason}'
+            )
+        return await res.json()
+
+
+class HttpError(Exception):
+    """
+    Raised when the response of an HTTP request has not a 200 status code.
+    """
+
+
+@dataclasses.dataclass()
+class ConnectorStatus:
+    status: Optional[bool] = None
+    message: Optional[str] = None
+    error: Optional[str] = None
+    details: Optional[List[Tuple[str, Optional[bool]]]] = dataclasses.field(default_factory=list)
+
+    def to_dict(self):
+        return dataclasses.asdict(self)
