@@ -11,7 +11,7 @@ import pandas as pd
 import tenacity as tny
 from pydantic import BaseModel
 
-from toucan_connectors.common import apply_query_parameters
+from toucan_connectors.common import ConnectorStatus, apply_query_parameters
 from toucan_connectors.pandas_translator import PandasConditionTranslator
 
 try:
@@ -206,7 +206,9 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
             cls.bearer_integration = cls.__fields__['bearer_integration'].default
 
     def bearer_oauth_get_endpoint(
-        self, endpoint: str, query: Optional[dict] = None,
+        self,
+        endpoint: str,
+        query: Optional[dict] = None,
     ):
         """Generic method to get an endpoint for an OAuth API integrated with Bearer"""
         return (
@@ -223,18 +225,28 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         return RetryPolicy(**kwargs)
 
     @abstractmethod
-    def _retrieve_data(self, data_source: ToucanDataSource):
+    def _retrieve_data(self, data_source: ToucanDataSource, **kwargs):
         """Main method to retrieve a pandas dataframe"""
 
     @decorate_func_with_retry
     def get_df(
-        self, data_source: ToucanDataSource, permissions: Optional[dict] = None
+        self,
+        data_source: ToucanDataSource,
+        permissions: Optional[dict] = None,
+        **kwargs,
     ) -> pd.DataFrame:
         """
         Method to retrieve the data as a pandas dataframe
         filtered by permissions
         """
-        res = self._retrieve_data(data_source)
+        # This conditional prevents passing secrets in kwargs to connectors that can't use them
+        # inspect module's signature object can't be used here in Python 3.6 because it is not
+        # generated the same way as in 3.7 and 3.8; this can be eventually replaced
+        if hasattr(self, '_auth_flow'):
+            res = self._retrieve_data(data_source, **kwargs)
+        else:
+            res = self._retrieve_data(data_source)
+
         if permissions is not None:
             permissions_query = PandasConditionTranslator.translate(permissions)
             permissions_query = apply_query_parameters(permissions_query, data_source.parameters)
@@ -247,6 +259,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         permissions: Optional[dict] = None,
         offset: int = 0,
         limit: Optional[int] = None,
+        **kwargs,
     ) -> DataSlice:
         """
         Method to retrieve a part of the data as a pandas dataframe
@@ -256,7 +269,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         - limit is the number of rows to retrieve
         Exemple: if offset = 5 and limit = 10 then 10 results are expected from 6th row
         """
-        df = self.get_df(data_source, permissions)
+        df = self.get_df(data_source, permissions, **kwargs)
         if limit is not None:
             return DataSlice(df[offset : offset + limit], len(df))
         else:
@@ -276,7 +289,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
             s.connect((host, port))
 
-    def get_status(self) -> dict:
+    def get_status(self) -> ConnectorStatus:
         """
         Check if connection can be made.
         Returns
@@ -284,6 +297,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
           'status': True/False/None  # the status of the connection (None if no check has been made)
           'details': [(< type of check >, True/False/None), (...), ...]
           'error': < error message >  # if a check raised an error, return it
+          'message': < status message > # optionally provides some additional info, such as the user account connected
         }
         e.g.
         {
@@ -297,4 +311,9 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
           'error': 'port must be 0-65535'
         }
         """
-        return {'status': None, 'details': [], 'error': None}
+        return ConnectorStatus()
+
+    def set_get_secrets(self, get_secrets):
+        print(self)
+        if self.auth_flow_id:
+            self._get_secrets = get_secrets(self.auth_flow_id)
